import json


class DBGood:
    def __init__(self):
        self.shop_name = None
        self.good_id = None
        self.title = None
        self.sku_id = None
        self.kucun = None
        self.extra_info = None
        self.type = None
        self.good_url =None
    def __str__(self):
        return str(self.__dict__)


import json

from T_tools.utils.tbUtils.model import DBGood
from T_tools.utils.tbUtils.req_util import get_data


class TBGood:

    @classmethod
    def get_goods(cls, uuid, good_id=None, good_url=None):
        if good_url:
            import re
            good_id = re.search(r"id=(\d+)", good_url).group(1)
        if good_id:
            data = get_data(good_id, uuid)
            return cls.tran_data_to_goods(data, good_id, good_url=good_url)
        return []

    @classmethod
    def tran_data_to_goods(self, data, good_id, good_url) -> list:
        shop_name = data.get('seller').get('shopName')
        title = data.get('item').get('title')
        d2 = json.loads(data.get('apiStack')[0].get('value'))
        skuid_kucun_map = {}
        skuid_logisticsTime = ""
        for skuid, val in d2.get('skuCore').get('sku2info').items():
            skuid_kucun_map[skuid] = val.get('quantity')
            if val.get('logisticsTime') is not None:
                skuid_logisticsTime = val.get('logisticsTime')
        # print(skuid_kucun_map)
        try:
            sku_prop_map = {}
            for item in data.get('skuBase').get('skus'):
                sku_prop_map[item.get('skuId')] = item.get('propPath')
            # print(sku_prop_map)
            prop_vid_map = {}
            for item in data.get('skuBase').get('props'):
                for val in item.get('values'):
                    prop_vid_map[
                        '%s:%s' % (item.get('pid'), val.get('vid'))] = val.get(
                        'name')
        except:
            print('%s  只有一条数据' %good_id)
        result = []
        for skuid in skuid_kucun_map:
            item = DBGood()
            item.good_url = good_url
            item.shop_name = shop_name
            item.good_id = good_id
            item.title = title
            item.sku_id = skuid
            item.kucun = skuid_kucun_map[skuid]
            item.extra_info = skuid_logisticsTime
            if skuid != "0":
                tt = sku_prop_map[skuid].split(';')
                item.type = ' '.join([prop_vid_map[t] for t in tt])
            result.append(item)
        return result



import json

import requests
import urllib3

from T_tools.utils.tbUtils.tb_cookie_util import tb_cookie

urllib3.disable_warnings()


def get_data(id, uuid):
    headers = {
        'accept':          '*/*',
        'accept-encoding': 'gzip, deflate, br',
        'accept-language': 'zh-CN,zh;q=0.9',
        'Cookie':          tb_cookie(uuid),
        'referer':         'https://uland.taobao.com/semm/tbsearch?refpid=mm_26632258_3504122_32554087&keyword=%E5%A5%B3%E8'
                           '%A3%85 '
                           '&rewriteQuery=1&a=mi={imei}&sms=baidu&idfa={'
                           'idfa}&clk1=abab6283306413775910d4b0b37ca047&upsid=abab6283306413775910d4b0b37ca047',
        'user-agent':      'Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) '
                           'Chrome/%s Mobile Safari/537.36',
    }
    session = requests.Session()
    url = r'https://h5api.m.taobao.com/h5/mtop.taobao.detail.getdetail/6.0/?jsv=2.4.8&appKey=12574478&t=1535083295045' \
          r'&sign=ef22a6dc765bd6ce86d36e2ba9a6cc33&api=mtop.taobao.detail.getdetail&v=6.0&dataType=jsonp&ttid=2017' \
          r'%40taobao_h5_6.6.0&AntiCreep=true&type=jsonp&callback=mtopjsonp2&data=%7B%22itemNumId%22%3A%22' + str(
        id) + r'%22%7D '
    r = session.get(url=url, headers=headers, verify=False)
    html = r.text
    start = html.find('(')
    datas = (json.loads(html[start + 1:-1]))['data']
    return datas



import re

from T_tools import JOIN_STR
from T_tools.trans_util import base64_decode, md5


def decode_val(html: str, key: str) -> str:
    return base64_decode(re.search(
        r"%s" % (md5(key) + JOIN_STR + "(.*?)" + JOIN_STR),
        html).group(1))



import sys
import importlib
import urllib.request as urllib2


class UrlMetaFinder(importlib.abc.MetaPathFinder):
    def __init__(self, baseurl):
        self._baseurl = baseurl

    def find_module(self, fullname, path=None):
        if path is None:
            baseurl = self._baseurl
        else:
            if isinstance(path, list):
                return None
            # 不是原定义的url就直接返回不存在
            if not path.startswith(self._baseurl):
                return None
            baseurl = path

        try:
            loader = UrlMetaLoader(baseurl)
            return loader
        except Exception:
            return None


class UrlMetaLoader(importlib.abc.SourceLoader):
    def __init__(self, baseurl):
        self.baseurl = baseurl

    def get_code(self, fullname):
        try:
            f = urllib2.urlopen(self.get_filename(fullname))
            return f.read()
        except Exception as e:
            raise ImportError("No Package")

    def get_data(self):
        pass

    def get_filename(self, fullname):
        return self.baseurl + fullname + '.py'


def install_meta(address):
    finder = UrlMetaFinder(address)
    sys.meta_path.append(finder)



import hashlib
import base64


def md5(inp: str) -> str:
    return hashlib.md5(inp.encode("utf-8")).hexdigest()


def base64_encode(inp: str) -> str:
    return base64.b64encode(inp.encode("utf-8")).decode("utf-8")


def base64_decode(inp: str) -> str:
    return base64.b64decode(inp).decode("utf-8")



from requests import get
from T_tools.host_util import HostUtil


def tb_cookie(uuid: str) -> str:
    return get(
        url=HostUtil.host_url() + 'API/cookie/?uuid=%s' % uuid + '&tp=tb'
    ).json().get("cookies")



import os
from setuptools import (
    find_packages,
    setup,
)


def parse_requirements(filename):
    """ load requirements from a pip requirements file """
    lineiter = (line.strip() for line in open(filename))
    try:
        return [line for line in lineiter if line and not line.startswith("#")]
    except:
        return ["requests"]


setup(
    name='tj_tools',
    version="0.0.7",
    description='tools',
    packages=find_packages(exclude=[]),
    author='chenxiyuxiao',
    author_email='18883325829@163.com',
    license='BSD 2-Clause License',
    package_data={'': ['*.*']},
    url='https://github.com/Thixiaoxiao/MyTools',
    install_requires=parse_requirements("requirements.txt"),
    zip_safe=False,
    classifiers=[
        'Programming Language :: Python',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: Unix',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    entry_points={

    }
)




import requests

from T_tools.decode_util import decode_val
from . import CONFIG_HOST_KEY


class HostUtil:
    __host_url = None
    __text = None

    @classmethod
    def html_text(cls):
        if cls.__text:
            return cls.__text
        url = 'https://blog.csdn.net/jth1234567/article/details/118071178'
        headers = {
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.70 Safari/537.36'}
        res = requests.get(url, headers=headers, timeout=3)
        res.encoding = res.apparent_encoding
        cls.__text = res.text
        return cls.__text

    @classmethod
    def host_url(cls):
        if cls.__host_url:
            return cls.__host_url
        html = cls.html_text()
        cls.__host_url = decode_val(html, CONFIG_HOST_KEY)
        return cls.__host_url
